# Setting Up Ionic Capacitor and Creating a Sample App using Pointr Cordova Plugin

## Step 1: Install Node.js and npm
Ensure you have Node.js and npm installed. You can download and install them from [nodejs.org](https://nodejs.org/).

## Step 2: Install Ionic CLI
Open your terminal and run:
```bash
npm install -g @ionic/cli
```

## Step 3: Create a New Ionic App
Create a new Ionic app named `test-pointr-cordova`:
```bash
ionic start test-pointr-cordova blank --type=angular --capacitor --package-id=<YOUR-PACKAGE>
```
Navigate into the project directory:
```bash
cd test-pointr-cordova
```

## Step 6: Add Platforms
Add the platforms you want to support (iOS and Android):
```bash
npm install @capacitor/ios
npm install @capacitor/android
npx cap add ios
npx cap add android
```

## Step 7: Download and Configure the Pointr plugin
Download and extract [`cordova-plugin-pointr`](https://pointrapps.blob.core.windows.net/pointr-docs/cordova-plugin-pointr-version-8.14.0.zip).

## Step 8: Configure the Pointr plugin

=== "iOS"

    Create folder `libs` under `cordova-plugin-pointr`.
    Download [the latest iOS SDK](https://pointrapps.blob.core.windows.net/pointr-docs/PointrKit-ios.8.14.0.zip) and move extracted `PointrKit.xcframework` and `Mapbox.xcframework` under newly created `libs` folder of `cordova-plugin-pointr`.

=== "Android"

    Update `android/variables.gradle` file, `ptrusername` and `ptrpassword` fields with the values given by the Pointr Project Manager. These are the credentials to access Pointr's Maven repository.

## Step 9: Install the Pointr plugin
Install the plugin using `npm` command under the project folder:
```bash
npm install <path to cordova-plugin-pointr`
```

## Step 10: App integration
Plugin functionality is accessible from scripts where it is declared: 
```TypeScript
declare let PointrPlugin: any;
...
PointrPlugin.showPoiDetails(function () {
    console.log("Showing Poi Details");
}, function (error) {
    console.log(error);
}, "<SITE_EXTERNAL_ID>", "<POI_ID>");
```
For example you can add a button that calls `showPoiDetails` at `home.page`. To do that go to `src/app/home/home.page.ts` file and declare `PointrPlugin`:
```typescript
import { Component } from '@angular/core';

declare let PointrPlugin: any;
```
Create a call to `initializeWithoutContent` function with the appropriate values at the constructor of `HomePage` class. This is to initialize the SDK:
```typescript
@Component({
  selector: 'app-home',
  templateUrl: 'home.page.html',
  styleUrls: ['home.page.scss'],
})
export class HomePage {

  constructor() {
    PointrPlugin.initializeWithoutContent(
        {},{}, 
        "<CLIEND_IDENTIFIER>",
        "<LICENSE_KEY>",
        "<BASE_URL>",
        "PROD",
        4
      );
...
```
Create a function called `showPoiDetails` that highlights a specific POI for the predefined site:
```typescript
export class HomePage {
...
    showPoiDetails() {
      PointrPlugin.showPoiDetails(function () {
          console.log("Showing Poi Details");
      }, function (error) {
          console.log(error);
      }, "<SITE_EXTERNAL_ID>", "<POI_ID>");
  }
...
}
```
Add an Ionic Button to `home.page.html` file that calls `showPoiDetails` function when clicked:
```html
  <ion-button (click)="showPoiDetails()">
    Show Poi Details
  </ion-button>
```
[API reference](https://docs.pointr.tech/docs/8.x/Developer%20Portal/API%20Reference/api%20ref-mobile/) can be checked for the available functionality.


## Step 11: Build the App
Build your Ionic app:
```bash
ionic build
```

## Step 12: Sync Capacitor
Sync the Capacitor configuration and web assets to the native platforms:
```bash
npx cap copy
npx cap sync
```

## Step 13: Open the Native IDEs

=== "iOS"

    Open the native IDEs to run your app on a device or simulator: 
    ```bash
    npx cap open ios
    ```
    Arrange the bundle id and signings of the app.
    Open file `ios/App/Info.plist` file and add the required [permissions](//docs/8.x/Developer%20Portal/Pointr%20Mobile%20SDK/Information/Operating%20System%20Permissions/).
    Run the project from XCode (should use real device to see the map)

=== "Android"
  
    Open the native IDEs to run your app on a device or simulator: 
    ```bash
    npx cap open android
    ```
    Configure the project to use JDK version 17 if it is not already the case.
    Add the custom maven repo to file `android\build.gradle` to download Pointr Mobile SDK: 
    ```
    allprojects {
        repositories {
            ...
            maven {
                url "https://android.pointr.dev/artifactory/gradle-release-local"
                credentials {
                    username rootProject.ext.ptrusername
                    password rootProject.ext.ptrpassword
                }
            }
            ...
        }
    }
    ```
    Run the project from IDE.